summaryrefslogtreecommitdiffstats
path: root/apps
diff options
context:
space:
mode:
Diffstat (limited to 'apps')
-rw-r--r--apps/files_sharing/tests/SharedStorageTest.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/apps/files_sharing/tests/SharedStorageTest.php b/apps/files_sharing/tests/SharedStorageTest.php
index 7d007cb6414..195016c47d1 100644
--- a/apps/files_sharing/tests/SharedStorageTest.php
+++ b/apps/files_sharing/tests/SharedStorageTest.php
@@ -207,10 +207,11 @@ class SharedStorageTest extends TestCase {
$this->assertTrue(\OC\Files\Filesystem::is_dir($this->folder));
// for the share root we expect:
// the read permissions (1)
// the delete permission (8), to enable unshare
$rootInfo = \OC\Files\Filesystem::getFileInfo($this->folder);
- $this->assertSame(9, $rootInfo->getPermissions());
+ $this->assertSame(\OCP\Constants::PERMISSION_READ | \OCP\Constants::PERMISSION_DELETE | \OCP\Constants::PERMISSION_UPDATE, $rootInfo->getPermissions());
// for the file within the shared folder we expect:
// the read permissions (1)
@@ -207,10 +207,11 @@ class SharedStorageTest extends TestCase {
$this->assertTrue(\OC\Files\Filesystem::is_dir($this->folder));
// for the share root we expect:
- // the read permissions (1)
- // the delete permission (8), to enable unshare
+ // the read permissions
+ // the delete permission, to enable unshare
+ // the update permission, to enable moving the share
$rootInfo = \OC\Files\Filesystem::getFileInfo($this->folder);